##LibName#Gauss-Test (2SP)
##LibDescription#Die Bibliothek enthlt eine Funktion zur Berechnung des Gausstests fr den 2-Stichprobenfall.
##LibCopyright#Ronja Foraita




gauss.test <- function(x, y, vx=vx, vy=vy, a = 0.05, alternative = "two.sided", mu = 0) {
##FunctionName#gauss.test
##FunctionDescription#X und Y sind Datenvektoren. Die bekannten Varianzen V(x) und V(Y) mssen angegeben werden.
##FunctionDescription#Optional ist die Angabe des Signifikanzniveaus (a), der Alternativhypothese (alternative) und des Differenzwertes (mu).
##FunctionSyntax#gauss.test(x, y, vx, vy, a = 0.05, alternative = "two.sided", mu = 0)

	n <- length(x)
	m <- length(y)	
        
        #Pruefgroesse	
	pg <- (mean(x) - mean(y) - mu)/sqrt(vx/n + vy/m)	


	
	#kritischer Wert
	if(alternative == "two.sided" || alternative == "t") {
		q1 <- qnorm(a/2)
		q2 <- qnorm(1 - a/2)
	}
	if(alternative == "less" || alternative == "l") {
		q <- qnorm(a)
	}
	if(alternative == "greater" || alternative == "g") {
		q <- qnorm(1 - a)
	}



	#p-Wert
	if(alternative == "two.sided" || alternative == "t") {
		if(pg > 0) {
			p <- 2 * (1 - pnorm(pg))
		}
		else {
			p <- 2 * pnorm(pg)
		}
	}
	if(alternative == "less" || alternative == "l") {
		p <- pnorm(pg)
	}
	if(alternative == "greater" || alternative == "g") {
		p <- 1 - pnorm(pg)
	}

	

	#Ausgabe
	cat("\n\n", "                         Gauss-Test", "\n\n")
	cat("               Gruppe:         x                 y", "\n")
	cat("    Stichprobenumfang:       n =", n, "           m =", m, "\n")
	cat("          Mittelwerte: mean(x) =", round(mean(x), digits = 3), "  mean(y) =", round(mean(y), digits = 3
		), "\n")
	cat("Varianzen (angegeben):  Var(x) =", round(vx, digits = 3), "       Var(y) =", round(vy, digits = 3), "\n")
	cat("Varianzen(geschaetzt):  Var(x) =", round(var(x), digits = 3), "   Var(y) =", round(var(y), digits = 3), 
		"\n\n")
	cat("    Signifikanzniveau:", a, "\n")
	cat("      Pruefgroesse Z :", round(pg, digits = 3), "\n")
	if(alternative == "greater" || alternative == "g") {
		cat("   Alternativhypotese: true difference in means is greater than 0", "\n")
		cat("      kritischer Wert:", round(q, digits = 4), "\n")
	}
	if(alternative == "less" || alternative == "l") {
		cat("  Alternativhypothese: true difference in means is less than 0", "\n")
		cat("      kritischer Wert:", round(q, digits = 4), "\n")
	}
	if(alternative == "two.sided" || alternative == "t") {
		cat("  Alternativhypothese: true difference in means is not equal to 0 ", "\n")
		cat("      kritische Werte:", round(q1, digits = 4), "<->", round(q2, digits = 4), "\n")
	}
	cat("               P-Wert:", round(p, digits = 4), "\n")
}
